@@ -93,8 +93,10 @@ class PsmPy:
                 logistic.fit(df_cleaned, treatment)
                 pscore = logistic.predict_proba(df_cleaned)[:, 1]
                 df_cleaned['propensity_score'] = pscore
-                df_cleaned['propensity_logit'] = np.array(
-                    logit(xi) for xi in pscore)
+                # df_cleaned['propensity_logit'] = np.array(
+                # logit(xi) for xi in pscore)
+                df_cleaned['propensity_logit'] = df_cleaned['propensity_score'].apply(
+                    lambda p: np.log(p/(1-p)))
                 appended_data.append(df_cleaned)
             # if some of majority class leftover after the folding for training:
             if majority_len_diff != 0:
@@ -123,8 +125,8 @@ class PsmPy:
                     logistic.fit(df_cleaned, treatment)
                     pscore = logistic.predict_proba(df_cleaned)[:, 1]
                     df_cleaned['propensity_score'] = pscore
-                    df_cleaned['propensity_logit'] = np.array(
-                        logit(xi) for xi in pscore)
+                    df_cleaned['propensity_logit'] = df_cleaned['propensity_score'].apply(
+                        lambda p: np.log(p/(1-p)))
                     appended_data.append(df_cleaned)
                 else:
                     majority_extra = majority[majority_trunc_len:]
@@ -136,8 +138,8 @@ class PsmPy:
                     logistic.fit(df_cleaned, treatment)
                     pscore = logistic.predict_proba(df_cleaned)[:, 1]
                     df_cleaned['propensity_score'] = pscore
-                    df_cleaned['propensity_logit'] = np.array(
-                        logit(xi) for xi in pscore)
+                    df_cleaned['propensity_logit'] = df_cleaned['propensity_score'].apply(
+                        lambda p: np.log(p/(1-p)))
                     appended_data.append(df_cleaned)
             else:
                 pass
@@ -185,8 +187,8 @@ class PsmPy:
             logistic.fit(df_cleaned, treatment)
             pscore = logistic.predict_proba(df_cleaned)[:, 1]
             df_cleaned['propensity_score'] = pscore
-            df_cleaned['propensity_logit'] = np.array(
-                logit(xi) for xi in pscore)
+            df_cleaned['propensity_logit'] = df_cleaned['propensity_score'].apply(
+                lambda p: np.log(p/(1-p)))
             predicted_data_reset = df_cleaned.reset_index()
 
             # merge with treatment df
